@@ -132,6 +132,13 @@ class SparseNdarray:
             if is_masked is None:
                 is_masked = False 
 
+        # Sometimes people put the numpy data class instead of the dtype.
+        # It's a common enough mistake that we ought to catch it here.
+        if not isinstance(dtype, numpy.dtype): 
+            dtype = numpy.dtype(dtype)
+        if not isinstance(index_dtype, numpy.dtype): 
+            index_dtype = numpy.dtype(index_dtype)
+
         self._dtype = dtype
         self._index_dtype = index_dtype
         self._is_masked = is_masked
@@ -1200,7 +1207,7 @@ def _extract_sparse_vector_to_dense(indices: numpy.ndarray, values: numpy.ndarra
         pass
     elif subset_summary.consecutive:
         start_pos = 0
-        first = subset_summary.first_index
+        first = indices.dtype.type(subset_summary.first_index) # avoid casting of uint64s to floats during subtraction.
         if subset_summary.search_first:
             start_pos = bisect_left(indices, first)
 
@@ -1269,7 +1276,7 @@ def _extract_sparse_vector_to_sparse(indices: numpy.ndarray, values: numpy.ndarr
 
     elif subset_summary.consecutive:
         start_pos = 0
-        first = subset_summary.first_index
+        first = indices.dtype.type(subset_summary.first_index) # avoid casting of uint64's to floats during subtraction.
         if subset_summary.search_first:
             start_pos = bisect_left(indices, first)
 
